# coding: utf-8

"""
    mongodb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CreateDBInstanceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'instance_id': 'str',
        'order_no': 'str'
    }

    attribute_map = {
        'instance_id': 'InstanceId',
        'order_no': 'OrderNO'
    }

    def __init__(self, instance_id=None, order_no=None, _configuration=None):  # noqa: E501
        """CreateDBInstanceResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._instance_id = None
        self._order_no = None
        self.discriminator = None

        if instance_id is not None:
            self.instance_id = instance_id
        if order_no is not None:
            self.order_no = order_no

    @property
    def instance_id(self):
        """Gets the instance_id of this CreateDBInstanceResponse.  # noqa: E501


        :return: The instance_id of this CreateDBInstanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this CreateDBInstanceResponse.


        :param instance_id: The instance_id of this CreateDBInstanceResponse.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def order_no(self):
        """Gets the order_no of this CreateDBInstanceResponse.  # noqa: E501


        :return: The order_no of this CreateDBInstanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._order_no

    @order_no.setter
    def order_no(self, order_no):
        """Sets the order_no of this CreateDBInstanceResponse.


        :param order_no: The order_no of this CreateDBInstanceResponse.  # noqa: E501
        :type: str
        """

        self._order_no = order_no

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateDBInstanceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDBInstanceResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDBInstanceResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    cen

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from volcenginesdkcen.models.associate_cen_bandwidth_package_request import AssociateCenBandwidthPackageRequest
from volcenginesdkcen.models.associate_cen_bandwidth_package_response import AssociateCenBandwidthPackageResponse
from volcenginesdkcen.models.attach_instance_to_cen_request import AttachInstanceToCenRequest
from volcenginesdkcen.models.attach_instance_to_cen_response import AttachInstanceToCenResponse
from volcenginesdkcen.models.attached_instance_for_describe_cen_attached_instances_output import AttachedInstanceForDescribeCenAttachedInstancesOutput
from volcenginesdkcen.models.cen_bandwidth_package_for_describe_cen_bandwidth_packages_output import CenBandwidthPackageForDescribeCenBandwidthPackagesOutput
from volcenginesdkcen.models.cen_for_describe_cens_output import CenForDescribeCensOutput
from volcenginesdkcen.models.cen_grant_rule_for_describe_grant_rules_to_cen_output import CenGrantRuleForDescribeGrantRulesToCenOutput
from volcenginesdkcen.models.cen_grant_rule_for_describe_instance_granted_rules_output import CenGrantRuleForDescribeInstanceGrantedRulesOutput
from volcenginesdkcen.models.cen_route_entry_for_describe_cen_route_entries_output import CenRouteEntryForDescribeCenRouteEntriesOutput
from volcenginesdkcen.models.create_cen_bandwidth_package_request import CreateCenBandwidthPackageRequest
from volcenginesdkcen.models.create_cen_bandwidth_package_response import CreateCenBandwidthPackageResponse
from volcenginesdkcen.models.create_cen_inter_region_bandwidth_request import CreateCenInterRegionBandwidthRequest
from volcenginesdkcen.models.create_cen_inter_region_bandwidth_response import CreateCenInterRegionBandwidthResponse
from volcenginesdkcen.models.create_cen_request import CreateCenRequest
from volcenginesdkcen.models.create_cen_response import CreateCenResponse
from volcenginesdkcen.models.create_cen_service_route_entry_request import CreateCenServiceRouteEntryRequest
from volcenginesdkcen.models.create_cen_service_route_entry_response import CreateCenServiceRouteEntryResponse
from volcenginesdkcen.models.delete_cen_bandwidth_package_request import DeleteCenBandwidthPackageRequest
from volcenginesdkcen.models.delete_cen_bandwidth_package_response import DeleteCenBandwidthPackageResponse
from volcenginesdkcen.models.delete_cen_inter_region_bandwidth_request import DeleteCenInterRegionBandwidthRequest
from volcenginesdkcen.models.delete_cen_inter_region_bandwidth_response import DeleteCenInterRegionBandwidthResponse
from volcenginesdkcen.models.delete_cen_request import DeleteCenRequest
from volcenginesdkcen.models.delete_cen_response import DeleteCenResponse
from volcenginesdkcen.models.describe_cen_attached_instance_attributes_request import DescribeCenAttachedInstanceAttributesRequest
from volcenginesdkcen.models.describe_cen_attached_instance_attributes_response import DescribeCenAttachedInstanceAttributesResponse
from volcenginesdkcen.models.describe_cen_attached_instances_request import DescribeCenAttachedInstancesRequest
from volcenginesdkcen.models.describe_cen_attached_instances_response import DescribeCenAttachedInstancesResponse
from volcenginesdkcen.models.describe_cen_attributes_request import DescribeCenAttributesRequest
from volcenginesdkcen.models.describe_cen_attributes_response import DescribeCenAttributesResponse
from volcenginesdkcen.models.describe_cen_bandwidth_package_attributes_request import DescribeCenBandwidthPackageAttributesRequest
from volcenginesdkcen.models.describe_cen_bandwidth_package_attributes_response import DescribeCenBandwidthPackageAttributesResponse
from volcenginesdkcen.models.describe_cen_bandwidth_packages_request import DescribeCenBandwidthPackagesRequest
from volcenginesdkcen.models.describe_cen_bandwidth_packages_response import DescribeCenBandwidthPackagesResponse
from volcenginesdkcen.models.describe_cen_inter_region_bandwidth_attributes_request import DescribeCenInterRegionBandwidthAttributesRequest
from volcenginesdkcen.models.describe_cen_inter_region_bandwidth_attributes_response import DescribeCenInterRegionBandwidthAttributesResponse
from volcenginesdkcen.models.describe_cen_inter_region_bandwidths_request import DescribeCenInterRegionBandwidthsRequest
from volcenginesdkcen.models.describe_cen_inter_region_bandwidths_response import DescribeCenInterRegionBandwidthsResponse
from volcenginesdkcen.models.describe_cen_route_entries_request import DescribeCenRouteEntriesRequest
from volcenginesdkcen.models.describe_cen_route_entries_response import DescribeCenRouteEntriesResponse
from volcenginesdkcen.models.describe_cens_request import DescribeCensRequest
from volcenginesdkcen.models.describe_cens_response import DescribeCensResponse
from volcenginesdkcen.models.describe_grant_rules_to_cen_request import DescribeGrantRulesToCenRequest
from volcenginesdkcen.models.describe_grant_rules_to_cen_response import DescribeGrantRulesToCenResponse
from volcenginesdkcen.models.describe_instance_granted_rules_request import DescribeInstanceGrantedRulesRequest
from volcenginesdkcen.models.describe_instance_granted_rules_response import DescribeInstanceGrantedRulesResponse
from volcenginesdkcen.models.detach_instance_from_cen_request import DetachInstanceFromCenRequest
from volcenginesdkcen.models.detach_instance_from_cen_response import DetachInstanceFromCenResponse
from volcenginesdkcen.models.disassociate_cen_bandwidth_package_request import DisassociateCenBandwidthPackageRequest
from volcenginesdkcen.models.disassociate_cen_bandwidth_package_response import DisassociateCenBandwidthPackageResponse
from volcenginesdkcen.models.grant_instance_to_cen_request import GrantInstanceToCenRequest
from volcenginesdkcen.models.grant_instance_to_cen_response import GrantInstanceToCenResponse
from volcenginesdkcen.models.inter_region_bandwidth_for_describe_cen_inter_region_bandwidths_output import InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput
from volcenginesdkcen.models.list_tags_for_resources_request import ListTagsForResourcesRequest
from volcenginesdkcen.models.list_tags_for_resources_response import ListTagsForResourcesResponse
from volcenginesdkcen.models.modify_cen_attributes_request import ModifyCenAttributesRequest
from volcenginesdkcen.models.modify_cen_attributes_response import ModifyCenAttributesResponse
from volcenginesdkcen.models.modify_cen_bandwidth_package_attributes_request import ModifyCenBandwidthPackageAttributesRequest
from volcenginesdkcen.models.modify_cen_bandwidth_package_attributes_response import ModifyCenBandwidthPackageAttributesResponse
from volcenginesdkcen.models.modify_cen_inter_region_bandwidth_attributes_request import ModifyCenInterRegionBandwidthAttributesRequest
from volcenginesdkcen.models.modify_cen_inter_region_bandwidth_attributes_response import ModifyCenInterRegionBandwidthAttributesResponse
from volcenginesdkcen.models.resource_tag_for_list_tags_for_resources_output import ResourceTagForListTagsForResourcesOutput
from volcenginesdkcen.models.revoke_instance_from_cen_request import RevokeInstanceFromCenRequest
from volcenginesdkcen.models.revoke_instance_from_cen_response import RevokeInstanceFromCenResponse
from volcenginesdkcen.models.tag_filter_for_describe_cen_bandwidth_packages_input import TagFilterForDescribeCenBandwidthPackagesInput
from volcenginesdkcen.models.tag_filter_for_describe_cens_input import TagFilterForDescribeCensInput
from volcenginesdkcen.models.tag_filter_for_list_tags_for_resources_input import TagFilterForListTagsForResourcesInput
from volcenginesdkcen.models.tag_for_create_cen_bandwidth_package_input import TagForCreateCenBandwidthPackageInput
from volcenginesdkcen.models.tag_for_create_cen_input import TagForCreateCenInput
from volcenginesdkcen.models.tag_for_describe_cen_attributes_output import TagForDescribeCenAttributesOutput
from volcenginesdkcen.models.tag_for_describe_cen_bandwidth_package_attributes_output import TagForDescribeCenBandwidthPackageAttributesOutput
from volcenginesdkcen.models.tag_for_describe_cen_bandwidth_packages_output import TagForDescribeCenBandwidthPackagesOutput
from volcenginesdkcen.models.tag_for_describe_cens_output import TagForDescribeCensOutput
from volcenginesdkcen.models.tag_for_tag_resources_input import TagForTagResourcesInput
from volcenginesdkcen.models.tag_resources_request import TagResourcesRequest
from volcenginesdkcen.models.tag_resources_response import TagResourcesResponse
from volcenginesdkcen.models.untag_resources_request import UntagResourcesRequest
from volcenginesdkcen.models.untag_resources_response import UntagResourcesResponse



# coding: utf-8

"""
    redis

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'private_download_url': 'str',
        'public_download_url': 'str',
        'rdb_file_size': 'int',
        'shard_id': 'str'
    }

    attribute_map = {
        'private_download_url': 'PrivateDownloadUrl',
        'public_download_url': 'PublicDownloadUrl',
        'rdb_file_size': 'RdbFileSize',
        'shard_id': 'ShardId'
    }

    def __init__(self, private_download_url=None, public_download_url=None, rdb_file_size=None, shard_id=None, _configuration=None):  # noqa: E501
        """BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._private_download_url = None
        self._public_download_url = None
        self._rdb_file_size = None
        self._shard_id = None
        self.discriminator = None

        if private_download_url is not None:
            self.private_download_url = private_download_url
        if public_download_url is not None:
            self.public_download_url = public_download_url
        if rdb_file_size is not None:
            self.rdb_file_size = rdb_file_size
        if shard_id is not None:
            self.shard_id = shard_id

    @property
    def private_download_url(self):
        """Gets the private_download_url of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501


        :return: The private_download_url of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501
        :rtype: str
        """
        return self._private_download_url

    @private_download_url.setter
    def private_download_url(self, private_download_url):
        """Sets the private_download_url of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.


        :param private_download_url: The private_download_url of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501
        :type: str
        """

        self._private_download_url = private_download_url

    @property
    def public_download_url(self):
        """Gets the public_download_url of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501


        :return: The public_download_url of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501
        :rtype: str
        """
        return self._public_download_url

    @public_download_url.setter
    def public_download_url(self, public_download_url):
        """Sets the public_download_url of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.


        :param public_download_url: The public_download_url of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501
        :type: str
        """

        self._public_download_url = public_download_url

    @property
    def rdb_file_size(self):
        """Gets the rdb_file_size of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501


        :return: The rdb_file_size of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501
        :rtype: int
        """
        return self._rdb_file_size

    @rdb_file_size.setter
    def rdb_file_size(self, rdb_file_size):
        """Sets the rdb_file_size of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.


        :param rdb_file_size: The rdb_file_size of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501
        :type: int
        """

        self._rdb_file_size = rdb_file_size

    @property
    def shard_id(self):
        """Gets the shard_id of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501


        :return: The shard_id of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501
        :rtype: str
        """
        return self._shard_id

    @shard_id.setter
    def shard_id(self, shard_id):
        """Sets the shard_id of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.


        :param shard_id: The shard_id of this BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput.  # noqa: E501
        :type: str
        """

        self._shard_id = shard_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput):
            return True

        return self.to_dict() != other.to_dict()



# -*- coding: utf-8 -*-

import time
from enum import Enum
from pprint import pprint

from volcenginesdkvke import (AutoScalingForUpdateNodePoolConfigInput,
                              ClusterConfigForCreateClusterInput,
                              CreateAddonRequest, CreateClusterRequest,
                              CreateNodePoolRequest,
                              FilterForListClustersInput,
                              FilterForListNodePoolsInput,
                              FilterForListNodesInput,
                              FlannelConfigForCreateClusterInput,
                              ListClustersRequest, ListNodePoolsRequest,
                              ListNodesRequest, LoginForCreateNodePoolInput,
                              NodeConfigForCreateNodePoolInput,
                              PodsConfigForCreateClusterInput,
                              SecurityForCreateNodePoolInput,
                              ServicesConfigForCreateClusterInput,
                              SystemVolumeForCreateNodePoolInput,
                              UpdateNodePoolConfigRequest,
                              VpcCniConfigForCreateClusterInput)


class NetworkMode(Enum):

    Flannel = "Flannel"
    VpcCniShared = "VpcCniShared"


class VKEOption:
    """包含搭建最基本的VKE服务的选项"""

    def __init__(
        self,
        cluster_name,
        network_mode,
        node_pool_name,
        instance_type,
        password,
        subnet_ids,
        service_cidrs,
        pod_cidrs=None,
        api_server_public_access_enabled=False,
        auto_scaling=False,
    ):

        self.cluster_name = cluster_name
        self.network_mode = network_mode
        self.node_pool_name = node_pool_name
        self.instance_type = instance_type
        self.password = password
        self.subnet_ids = subnet_ids
        self.service_cidrs = service_cidrs
        self.pod_cidrs = pod_cidrs
        self.api_server_public_access_enabled = api_server_public_access_enabled
        self.auto_scaling = auto_scaling


def create_pods_config(opt):
    """根据用户提供的集群NetworkMode类型，创建PodConfig"""
    network_mode = opt.network_mode
    if network_mode == NetworkMode.Flannel.value:
        pod_config = PodsConfigForCreateClusterInput(
            pod_network_mode=NetworkMode.Flannel.value,
            flannel_config=FlannelConfigForCreateClusterInput(
                pod_cidrs=opt.pod_cidrs,
            ),
        )
    elif network_mode == NetworkMode.VpcCniShared.value:
        pod_config = PodsConfigForCreateClusterInput(
            pod_network_mode=NetworkMode.VpcCniShared.value,
            vpc_cni_config=VpcCniConfigForCreateClusterInput(
                subnet_ids=opt.subnet_ids,
            ),
        )
    else:
        raise ValueError(
            "Network mode: {network_mode} is not accepted. Please choose from: 'Flannel' and 'VpcCniShared'.".format(
                network_mode=network_mode
            )
        )
    return pod_config


def create_cluster(vke_api, name, cluster_config, pods_config, services_config):
    """创建VKE集群"""
    req = CreateClusterRequest(
        cluster_config=cluster_config,
        name=name,
        pods_config=pods_config,
        services_config=services_config,
    )
    return vke_api.create_cluster(req)


def get_cluster(vke_api, cluster_id):
    """获取指定ID的集群信息"""
    req = ListClustersRequest(filter=FilterForListClustersInput(ids=[cluster_id]))
    return vke_api.list_clusters(req)


def create_node_pool(
    vke_api, cluster_id, node_pool_name, instance_type, password, subnet_ids
):
    """创建节点池"""
    node_config = NodeConfigForCreateNodePoolInput(
        instance_type_ids=[instance_type],
        security=SecurityForCreateNodePoolInput(
            login=LoginForCreateNodePoolInput(password=password),
        ),
        subnet_ids=subnet_ids,
        system_volume=SystemVolumeForCreateNodePoolInput(size=40, type="ESSD_PL0"),
    )
    req = CreateNodePoolRequest(
        cluster_id=cluster_id,
        name=node_pool_name,
        node_config=node_config,
    )
    return vke_api.create_node_pool(req)


def get_node_pool(vke_api, node_pool_id):
    """获取指定ID的节点池信息"""
    req = ListNodePoolsRequest(filter=FilterForListNodePoolsInput(ids=[node_pool_id]))
    return vke_api.list_node_pools(req)


def update_node_pool(vke_api, cluster_id, node_pool_id, auto_scaling):
    """更新节点池节点数量"""
    replicas = 1
    if auto_scaling:
        replicas = 0
    req = UpdateNodePoolConfigRequest(
        cluster_id=cluster_id,
        id=node_pool_id,
        auto_scaling=AutoScalingForUpdateNodePoolConfigInput(
            enabled=auto_scaling,
            desired_replicas=replicas,
        ),
    )
    return vke_api.update_node_pool_config(req)


def list_nodes(vke_api, node_pool_id):
    """获取指定ID的节点池的节点信息"""
    req = ListNodesRequest(filter=FilterForListNodesInput(node_pool_ids=[node_pool_id]))
    return vke_api.list_nodes(req)


def install_addon(vke_api, cluster_id):
    """安装插件"""
    # 在每个addon安装之后，sleep 5秒
    _interval = 5
    metrics_server_req = CreateAddonRequest(
        cluster_id=cluster_id, name="metrics-server"
    )
    metrics_server_resp = vke_api.create_addon(metrics_server_req)
    pprint(metrics_server_resp)

    time.sleep(_interval)

    coredns_req = CreateAddonRequest(cluster_id=cluster_id, name="core-dns")
    coredns_resp = vke_api.create_addon(coredns_req)
    pprint(coredns_resp)

    time.sleep(_interval)

    cluster_autoscaler_req = CreateAddonRequest(
        cluster_id=cluster_id,
        name="cluster-autoscaler",
        config='{"Expander":"random"}',
    )
    cluster_autoscaler_resp = vke_api.create_addon(cluster_autoscaler_req)
    pprint(cluster_autoscaler_resp)


def create_vke(vke_api, opt):
    """创建VKE服务"""
    pods_config = create_pods_config(opt)
    cluster_config = ClusterConfigForCreateClusterInput(
        api_server_public_access_enabled=opt.api_server_public_access_enabled,
        subnet_ids=opt.subnet_ids,
    )
    services_config = ServicesConfigForCreateClusterInput(
        service_cidrsv4=opt.service_cidrs
    )

    # 1. 创建集群
    create_cluster_resp = create_cluster(
        vke_api, opt.cluster_name, cluster_config, pods_config, services_config
    )
    cluster_id = create_cluster_resp.to_dict().get("id")
    pprint("cluster id: {}".format(cluster_id))

    # 2. 查询集群状态
    while True:
        get_cluser_resp = get_cluster(vke_api, cluster_id)
        results = get_cluser_resp.to_dict().get("items")
        if len(results) > 0 and results[0].get("status", {}).get("phase") == "Running":
            break
        time.sleep(10)

    # 3. 创建节点池
    create_node_pool_resp = create_node_pool(
        vke_api,
        cluster_id,
        opt.node_pool_name,
        opt.instance_type,
        opt.password,
        opt.subnet_ids,
    )
    node_pool_id = create_node_pool_resp.to_dict().get("id")
    pprint("node pool id: {}".format(node_pool_id))

    # 4. 查看节点池
    while True:
        get_node_pool_resp = get_node_pool(vke_api, node_pool_id)
        results = get_node_pool_resp.to_dict().get("items")
        if len(results) > 0 and results[0].get("status", {}).get("phase") == "Running":
            break
        time.sleep(10)
    pprint("node pool:")
    pprint(results)

    # 5. 查看节点列表
    list_nodes_resp = list_nodes(vke_api, node_pool_id)
    results = list_nodes_resp.to_dict().get("items")
    pprint("node list:")
    pprint(results)

    # 6. 安装组件 & 设置节点池弹性策略
    pprint("install addon (including cluster-autoscaler)")
    install_addon(vke_api, cluster_id)

    # 7. 修改节点数量
    pprint("update node pool")
    update_node_pool_resp = update_node_pool(
        vke_api,
        cluster_id,
        node_pool_id,
        auto_scaling=opt.auto_scaling,
    )
    pprint(update_node_pool_resp)

    # 8. 查看节点列表
    pprint("check nodes count")
    while len(results) == 0:
        list_nodes_resp = list_nodes(vke_api, node_pool_id)
        results = list_nodes_resp.to_dict().get("items")
        time.sleep(10)
    pprint("node list:")
    pprint(results)



# coding: utf-8

from volcenginesdkcore import ApiClient
import six


class UniversalInfo(object):
    def __init__(self, method=None, service=None, version=None, action=None, content_type=None):
        self.method = method
        self.service = service
        self.version = version
        self.action = action
        self.content_type = content_type


class UniversalApi(object):

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def do_call(self, info, body, **kwargs):  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.do_call_with_http_info(info, body, **kwargs)  # noqa: E501
        else:
            (data) = self.do_call_with_http_info(info, body, **kwargs)  # noqa: E501
            return data

    def do_call_with_http_info(self, info, body, **kwargs):  # noqa: E501
        all_params = ['body', 'async_req', '_return_http_data_only', '_preload_content',
                      '_request_timeout']  # noqa: E501

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method do_call" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `body` when calling `do_call`")  # noqa: E501

        if type(params['body']) is not dict:
            raise TypeError(
                "The required parameter `body` must be dict")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        if info.content_type is not None:
            # HTTP header `Content-Type`
            header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
                [info.content_type])  # noqa: E501

        if info.method.lower() == "get":
            query_params = list(body.items())

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        path = '/' + info.action + '/' + info.version + '/' + info.service + '/' + info.method.lower() + '/'
        return self.api_client.call_api(
            path, info.method.upper(),
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=object,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    vpn

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

import volcenginesdkcore


class VPNApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = volcenginesdkcore.ApiClient()
        self.api_client = api_client

    def create_customer_gateway(self, body, **kwargs):  # noqa: E501
        """create_customer_gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_customer_gateway(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustomerGatewayRequest body: (required)
        :return: CreateCustomerGatewayResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_customer_gateway_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_customer_gateway_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_customer_gateway_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_customer_gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_customer_gateway_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustomerGatewayRequest body: (required)
        :return: CreateCustomerGatewayResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_customer_gateway" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_customer_gateway`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateCustomerGateway/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateCustomerGatewayResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_vpn_connection(self, body, **kwargs):  # noqa: E501
        """create_vpn_connection  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_vpn_connection(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateVpnConnectionRequest body: (required)
        :return: CreateVpnConnectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_vpn_connection_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_vpn_connection_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_vpn_connection_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_vpn_connection  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_vpn_connection_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateVpnConnectionRequest body: (required)
        :return: CreateVpnConnectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_vpn_connection" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_vpn_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateVpnConnection/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateVpnConnectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_vpn_gateway(self, body, **kwargs):  # noqa: E501
        """create_vpn_gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_vpn_gateway(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateVpnGatewayRequest body: (required)
        :return: CreateVpnGatewayResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_vpn_gateway_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_vpn_gateway_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_vpn_gateway_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_vpn_gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_vpn_gateway_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateVpnGatewayRequest body: (required)
        :return: CreateVpnGatewayResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_vpn_gateway" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_vpn_gateway`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateVpnGateway/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateVpnGatewayResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_vpn_gateway_route(self, body, **kwargs):  # noqa: E501
        """create_vpn_gateway_route  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_vpn_gateway_route(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateVpnGatewayRouteRequest body: (required)
        :return: CreateVpnGatewayRouteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_vpn_gateway_route_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_vpn_gateway_route_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_vpn_gateway_route_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_vpn_gateway_route  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_vpn_gateway_route_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateVpnGatewayRouteRequest body: (required)
        :return: CreateVpnGatewayRouteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_vpn_gateway_route" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_vpn_gateway_route`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateVpnGatewayRoute/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateVpnGatewayRouteResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_customer_gateway(self, body, **kwargs):  # noqa: E501
        """delete_customer_gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_customer_gateway(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteCustomerGatewayRequest body: (required)
        :return: DeleteCustomerGatewayResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_customer_gateway_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_customer_gateway_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def delete_customer_gateway_with_http_info(self, body, **kwargs):  # noqa: E501
        """delete_customer_gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_customer_gateway_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteCustomerGatewayRequest body: (required)
        :return: DeleteCustomerGatewayResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_customer_gateway" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `delete_customer_gateway`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DeleteCustomerGateway/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteCustomerGatewayResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_vpn_connection(self, body, **kwargs):  # noqa: E501
        """delete_vpn_connection  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vpn_connection(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteVpnConnectionRequest body: (required)
        :return: DeleteVpnConnectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_vpn_connection_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_vpn_connection_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def delete_vpn_connection_with_http_info(self, body, **kwargs):  # noqa: E501
        """delete_vpn_connection  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vpn_connection_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteVpnConnectionRequest body: (required)
        :return: DeleteVpnConnectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_vpn_connection" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `delete_vpn_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DeleteVpnConnection/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteVpnConnectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_vpn_gateway(self, body, **kwargs):  # noqa: E501
        """delete_vpn_gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vpn_gateway(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteVpnGatewayRequest body: (required)
        :return: DeleteVpnGatewayResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_vpn_gateway_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_vpn_gateway_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def delete_vpn_gateway_with_http_info(self, body, **kwargs):  # noqa: E501
        """delete_vpn_gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vpn_gateway_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteVpnGatewayRequest body: (required)
        :return: DeleteVpnGatewayResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_vpn_gateway" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `delete_vpn_gateway`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DeleteVpnGateway/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteVpnGatewayResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_vpn_gateway_route(self, body, **kwargs):  # noqa: E501
        """delete_vpn_gateway_route  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vpn_gateway_route(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteVpnGatewayRouteRequest body: (required)
        :return: DeleteVpnGatewayRouteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_vpn_gateway_route_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_vpn_gateway_route_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def delete_vpn_gateway_route_with_http_info(self, body, **kwargs):  # noqa: E501
        """delete_vpn_gateway_route  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vpn_gateway_route_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteVpnGatewayRouteRequest body: (required)
        :return: DeleteVpnGatewayRouteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_vpn_gateway_route" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `delete_vpn_gateway_route`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DeleteVpnGatewayRoute/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteVpnGatewayRouteResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_customer_gateway_attributes(self, body, **kwargs):  # noqa: E501
        """describe_customer_gateway_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_customer_gateway_attributes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeCustomerGatewayAttributesRequest body: (required)
        :return: DescribeCustomerGatewayAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_customer_gateway_attributes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_customer_gateway_attributes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def describe_customer_gateway_attributes_with_http_info(self, body, **kwargs):  # noqa: E501
        """describe_customer_gateway_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_customer_gateway_attributes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeCustomerGatewayAttributesRequest body: (required)
        :return: DescribeCustomerGatewayAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_customer_gateway_attributes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `describe_customer_gateway_attributes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DescribeCustomerGatewayAttributes/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DescribeCustomerGatewayAttributesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_customer_gateways(self, body, **kwargs):  # noqa: E501
        """describe_customer_gateways  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_customer_gateways(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeCustomerGatewaysRequest body: (required)
        :return: DescribeCustomerGatewaysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_customer_gateways_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_customer_gateways_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def describe_customer_gateways_with_http_info(self, body, **kwargs):  # noqa: E501
        """describe_customer_gateways  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_customer_gateways_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeCustomerGatewaysRequest body: (required)
        :return: DescribeCustomerGatewaysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_customer_gateways" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `describe_customer_gateways`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DescribeCustomerGateways/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DescribeCustomerGatewaysResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_vpn_connection_attributes(self, body, **kwargs):  # noqa: E501
        """describe_vpn_connection_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_connection_attributes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnConnectionAttributesRequest body: (required)
        :return: DescribeVpnConnectionAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_vpn_connection_attributes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_vpn_connection_attributes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def describe_vpn_connection_attributes_with_http_info(self, body, **kwargs):  # noqa: E501
        """describe_vpn_connection_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_connection_attributes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnConnectionAttributesRequest body: (required)
        :return: DescribeVpnConnectionAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_vpn_connection_attributes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `describe_vpn_connection_attributes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DescribeVpnConnectionAttributes/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DescribeVpnConnectionAttributesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_vpn_connections(self, body, **kwargs):  # noqa: E501
        """describe_vpn_connections  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_connections(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnConnectionsRequest body: (required)
        :return: DescribeVpnConnectionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_vpn_connections_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_vpn_connections_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def describe_vpn_connections_with_http_info(self, body, **kwargs):  # noqa: E501
        """describe_vpn_connections  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_connections_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnConnectionsRequest body: (required)
        :return: DescribeVpnConnectionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_vpn_connections" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `describe_vpn_connections`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DescribeVpnConnections/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DescribeVpnConnectionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_vpn_gateway_attributes(self, body, **kwargs):  # noqa: E501
        """describe_vpn_gateway_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_gateway_attributes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnGatewayAttributesRequest body: (required)
        :return: DescribeVpnGatewayAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_vpn_gateway_attributes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_vpn_gateway_attributes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def describe_vpn_gateway_attributes_with_http_info(self, body, **kwargs):  # noqa: E501
        """describe_vpn_gateway_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_gateway_attributes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnGatewayAttributesRequest body: (required)
        :return: DescribeVpnGatewayAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_vpn_gateway_attributes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `describe_vpn_gateway_attributes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DescribeVpnGatewayAttributes/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DescribeVpnGatewayAttributesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_vpn_gateway_route_attributes(self, body, **kwargs):  # noqa: E501
        """describe_vpn_gateway_route_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_gateway_route_attributes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnGatewayRouteAttributesRequest body: (required)
        :return: DescribeVpnGatewayRouteAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_vpn_gateway_route_attributes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_vpn_gateway_route_attributes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def describe_vpn_gateway_route_attributes_with_http_info(self, body, **kwargs):  # noqa: E501
        """describe_vpn_gateway_route_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_gateway_route_attributes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnGatewayRouteAttributesRequest body: (required)
        :return: DescribeVpnGatewayRouteAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_vpn_gateway_route_attributes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `describe_vpn_gateway_route_attributes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DescribeVpnGatewayRouteAttributes/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DescribeVpnGatewayRouteAttributesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_vpn_gateway_routes(self, body, **kwargs):  # noqa: E501
        """describe_vpn_gateway_routes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_gateway_routes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnGatewayRoutesRequest body: (required)
        :return: DescribeVpnGatewayRoutesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_vpn_gateway_routes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_vpn_gateway_routes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def describe_vpn_gateway_routes_with_http_info(self, body, **kwargs):  # noqa: E501
        """describe_vpn_gateway_routes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_gateway_routes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnGatewayRoutesRequest body: (required)
        :return: DescribeVpnGatewayRoutesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_vpn_gateway_routes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `describe_vpn_gateway_routes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DescribeVpnGatewayRoutes/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DescribeVpnGatewayRoutesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_vpn_gateways(self, body, **kwargs):  # noqa: E501
        """describe_vpn_gateways  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_gateways(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnGatewaysRequest body: (required)
        :return: DescribeVpnGatewaysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_vpn_gateways_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_vpn_gateways_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def describe_vpn_gateways_with_http_info(self, body, **kwargs):  # noqa: E501
        """describe_vpn_gateways  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_gateways_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnGatewaysRequest body: (required)
        :return: DescribeVpnGatewaysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_vpn_gateways" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `describe_vpn_gateways`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DescribeVpnGateways/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DescribeVpnGatewaysResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_vpn_gateways_billing(self, body, **kwargs):  # noqa: E501
        """describe_vpn_gateways_billing  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_gateways_billing(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnGatewaysBillingRequest body: (required)
        :return: DescribeVpnGatewaysBillingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_vpn_gateways_billing_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_vpn_gateways_billing_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def describe_vpn_gateways_billing_with_http_info(self, body, **kwargs):  # noqa: E501
        """describe_vpn_gateways_billing  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_vpn_gateways_billing_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVpnGatewaysBillingRequest body: (required)
        :return: DescribeVpnGatewaysBillingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_vpn_gateways_billing" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `describe_vpn_gateways_billing`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DescribeVpnGatewaysBilling/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DescribeVpnGatewaysBillingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def modify_customer_gateway_attributes(self, body, **kwargs):  # noqa: E501
        """modify_customer_gateway_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.modify_customer_gateway_attributes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModifyCustomerGatewayAttributesRequest body: (required)
        :return: ModifyCustomerGatewayAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.modify_customer_gateway_attributes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.modify_customer_gateway_attributes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def modify_customer_gateway_attributes_with_http_info(self, body, **kwargs):  # noqa: E501
        """modify_customer_gateway_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.modify_customer_gateway_attributes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModifyCustomerGatewayAttributesRequest body: (required)
        :return: ModifyCustomerGatewayAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method modify_customer_gateway_attributes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `modify_customer_gateway_attributes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ModifyCustomerGatewayAttributes/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModifyCustomerGatewayAttributesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def modify_vpn_connection_attributes(self, body, **kwargs):  # noqa: E501
        """modify_vpn_connection_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.modify_vpn_connection_attributes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModifyVpnConnectionAttributesRequest body: (required)
        :return: ModifyVpnConnectionAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.modify_vpn_connection_attributes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.modify_vpn_connection_attributes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def modify_vpn_connection_attributes_with_http_info(self, body, **kwargs):  # noqa: E501
        """modify_vpn_connection_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.modify_vpn_connection_attributes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModifyVpnConnectionAttributesRequest body: (required)
        :return: ModifyVpnConnectionAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method modify_vpn_connection_attributes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `modify_vpn_connection_attributes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ModifyVpnConnectionAttributes/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModifyVpnConnectionAttributesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def modify_vpn_gateway_attributes(self, body, **kwargs):  # noqa: E501
        """modify_vpn_gateway_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.modify_vpn_gateway_attributes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModifyVpnGatewayAttributesRequest body: (required)
        :return: ModifyVpnGatewayAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.modify_vpn_gateway_attributes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.modify_vpn_gateway_attributes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def modify_vpn_gateway_attributes_with_http_info(self, body, **kwargs):  # noqa: E501
        """modify_vpn_gateway_attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.modify_vpn_gateway_attributes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModifyVpnGatewayAttributesRequest body: (required)
        :return: ModifyVpnGatewayAttributesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method modify_vpn_gateway_attributes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `modify_vpn_gateway_attributes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ModifyVpnGatewayAttributes/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModifyVpnGatewayAttributesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def renew_vpn_gateway(self, body, **kwargs):  # noqa: E501
        """renew_vpn_gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.renew_vpn_gateway(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RenewVpnGatewayRequest body: (required)
        :return: RenewVpnGatewayResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.renew_vpn_gateway_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.renew_vpn_gateway_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def renew_vpn_gateway_with_http_info(self, body, **kwargs):  # noqa: E501
        """renew_vpn_gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.renew_vpn_gateway_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RenewVpnGatewayRequest body: (required)
        :return: RenewVpnGatewayResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method renew_vpn_gateway" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `renew_vpn_gateway`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/RenewVpnGateway/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RenewVpnGatewayResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_vpn_gateway_renewal(self, body, **kwargs):  # noqa: E501
        """set_vpn_gateway_renewal  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_vpn_gateway_renewal(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SetVpnGatewayRenewalRequest body: (required)
        :return: SetVpnGatewayRenewalResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_vpn_gateway_renewal_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.set_vpn_gateway_renewal_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def set_vpn_gateway_renewal_with_http_info(self, body, **kwargs):  # noqa: E501
        """set_vpn_gateway_renewal  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_vpn_gateway_renewal_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SetVpnGatewayRenewalRequest body: (required)
        :return: SetVpnGatewayRenewalResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_vpn_gateway_renewal" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `set_vpn_gateway_renewal`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/SetVpnGatewayRenewal/2020-04-01/vpn/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SetVpnGatewayRenewalResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    storage_ebs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

import volcenginesdkcore


class STORAGEEBSApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = volcenginesdkcore.ApiClient()
        self.api_client = api_client

    def attach_volume(self, body, **kwargs):  # noqa: E501
        """attach_volume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_volume(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AttachVolumeRequest body: (required)
        :return: AttachVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.attach_volume_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.attach_volume_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def attach_volume_with_http_info(self, body, **kwargs):  # noqa: E501
        """attach_volume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_volume_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AttachVolumeRequest body: (required)
        :return: AttachVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method attach_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `attach_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/AttachVolume/2020-04-01/storage_ebs/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttachVolumeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_volume(self, body, **kwargs):  # noqa: E501
        """create_volume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_volume(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateVolumeRequest body: (required)
        :return: CreateVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_volume_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_volume_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_volume_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_volume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_volume_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateVolumeRequest body: (required)
        :return: CreateVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateVolume/2020-04-01/storage_ebs/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateVolumeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_volume(self, body, **kwargs):  # noqa: E501
        """delete_volume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_volume(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteVolumeRequest body: (required)
        :return: DeleteVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_volume_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_volume_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def delete_volume_with_http_info(self, body, **kwargs):  # noqa: E501
        """delete_volume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_volume_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteVolumeRequest body: (required)
        :return: DeleteVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `delete_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DeleteVolume/2020-04-01/storage_ebs/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteVolumeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_volumes(self, body, **kwargs):  # noqa: E501
        """describe_volumes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_volumes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVolumesRequest body: (required)
        :return: DescribeVolumesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_volumes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_volumes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def describe_volumes_with_http_info(self, body, **kwargs):  # noqa: E501
        """describe_volumes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_volumes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DescribeVolumesRequest body: (required)
        :return: DescribeVolumesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_volumes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `describe_volumes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DescribeVolumes/2020-04-01/storage_ebs/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DescribeVolumesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def detach_volume(self, body, **kwargs):  # noqa: E501
        """detach_volume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detach_volume(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DetachVolumeRequest body: (required)
        :return: DetachVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.detach_volume_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.detach_volume_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def detach_volume_with_http_info(self, body, **kwargs):  # noqa: E501
        """detach_volume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detach_volume_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DetachVolumeRequest body: (required)
        :return: DetachVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method detach_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `detach_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DetachVolume/2020-04-01/storage_ebs/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DetachVolumeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def extend_volume(self, body, **kwargs):  # noqa: E501
        """extend_volume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.extend_volume(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExtendVolumeRequest body: (required)
        :return: ExtendVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.extend_volume_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.extend_volume_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def extend_volume_with_http_info(self, body, **kwargs):  # noqa: E501
        """extend_volume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.extend_volume_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExtendVolumeRequest body: (required)
        :return: ExtendVolumeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method extend_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `extend_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ExtendVolume/2020-04-01/storage_ebs/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ExtendVolumeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def modify_volume_attribute(self, body, **kwargs):  # noqa: E501
        """modify_volume_attribute  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.modify_volume_attribute(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModifyVolumeAttributeRequest body: (required)
        :return: ModifyVolumeAttributeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.modify_volume_attribute_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.modify_volume_attribute_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def modify_volume_attribute_with_http_info(self, body, **kwargs):  # noqa: E501
        """modify_volume_attribute  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.modify_volume_attribute_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModifyVolumeAttributeRequest body: (required)
        :return: ModifyVolumeAttributeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method modify_volume_attribute" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `modify_volume_attribute`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ModifyVolumeAttribute/2020-04-01/storage_ebs/get/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModifyVolumeAttributeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
